@@ -1,4 +1,4 @@
 from .misc import merge_two_dicts, flatten, is_float, is_factor
 
 
-__all__=[merge_two_dicts, flatten, is_float, is_factor]
\ No newline at end of file
+__all__ = ["merge_two_dicts", "flatten", "is_float", "is_factor"]
